==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ar/mail.php <==
<?php

return array(
    'a_user_canceled' => 'ألغى المستخدم طلب عنصر على الموقع',
    'a_user_requested' => 'طلب مستخدم عنصر على الموقع',
    'accessory_name' => 'اسم الملحق:',
    'additional_notes' => 'ملاحظات إضافية:',
    'admin_has_created' => 'قام مسؤول بإنشاء حساب لك على الموقع :web.',
    'asset' => 'أصل:',
    'asset_name' => 'اسم الأصل:',
    'asset_requested' => 'تم طلب مادة العرض',
    'asset_tag' => 'ترميز الأصل:',
    'assigned_to' => 'عينت الى',
    'best_regards' => 'أفضل التحيات،',
    'canceled' => 'ملغى:',
    'checkin_date' => 'تاريخ الادخال:',
    'checkout_date' => 'تاريخ الاخراج:',
    'click_to_confirm' => 'يرجى النقر على الرابط التالي لتأكيد حسابك على :web :',
    'click_on_the_link_accessory' => 'الرجاء النقر على الرابط الموجود في الأسفل لتأكيد استلامك للملحق.',
    'click_on_the_link_asset' => 'يرجى النقر على الرابط في الجزء السفلي للتأكد من أنك قد تلقيت مادة العرض.',
    'Confirm_Asset_Checkin' => 'تأكيد تسجيل الأصول',
    'Confirm_Accessory_Checkin' => 'تأكيد تسجيل الأصول',
    'Confirm_accessory_delivery' => 'تأكيد توصيل الأصول',
    'Confirm_license_delivery' => 'تأكيد توصيل الرخصة',
    'Confirm_asset_delivery' => 'تأكيد تسليم الأصول',
    'Confirm_consumable_delivery' => 'تأكيد التسليم المستهلكة',
    'current_QTY' => 'الكمية الحالية',
    'Days' => 'أيام',
    'days' => 'أيام',
    'expecting_checkin_date' => 'تاريخ الادخال المتوقع:',
    'expires' => 'ينتهي',
    'Expiring_Assets_Report' => 'تقرير الأصول المنتهية الصلاحية.',
    'Expiring_Licenses_Report' => 'تقرير التراخيص المنتهية الصلاحية.',
    'hello' => 'مرحبا',
    'hi' => 'مرحبا',
    'i_have_read' => 'لقد قرأت بنود الاستخدام وأوافق عليها، وقد تلقيت هذا البند.',
    'item' => 'عنصر:',
    'Item_Request_Canceled' => 'تم إلغاء طلب العنصر',
    'Item_Requested' => 'العنصر المطلوب',
    'link_to_update_password' => 'يرجى النقر على الرابط التالي لتحديث كلمة المرور الخاصة بك على :web :',
    'login_first_admin' => 'قم بتسجيل الدخول إلى التثبيت الجديد من Snipe-IT باستخدام البيانات أدناه:',
    'login' => 'تسجيل الدخول:',
    'Low_Inventory_Report' => 'تقرير المخزون المنخفض',
    'min_QTY' => 'دقيقة الكمية',
    'name' => 'اسم',
    'new_item_checked' => 'تم فحص عنصر جديد تحت اسمك، التفاصيل أدناه.',
    'password' => 'كلمة المرور:',
    'password_reset' => 'إعادة تعيين كلمة المرور',

    'read_the_terms' => 'يرجى قراءة شروط الاستخدام أدناه.',
    'read_the_terms_and_click' => 'يرجى قراءة بنود الاستخدام أدناه، والنقر على الرابط في الأسفل للتأكد من أنك تقرأ بنود الاستخدام ووافقت عليها، وتلقت مادة العرض.',
    'requested' => 'تم الطلب:',
    'reset_link' => 'رابط إعادة تعيين كلمة المرور',
    'reset_password' => 'انقر هنا لإعادة تعيين كلمة المرور:',
    'serial' => 'الرقم التسلسلي',
    'supplier' => 'المورد',
    'tag' => 'الترميز',
    'test_email' => 'اختبار البريد الإلكتروني من قنص-تكنولوجيا المعلومات',
    'test_mail_text' => 'يعتبر هذا اختبارا من نظام إدارة الأصول Snipe-IT. إذا كنت حصلت على هذا، فان البريد يعمل :)',
    'the_following_item' => 'تم ادخال العنصر التالي: ',
    'low_inventory_alert' => 'هنالك :count عناصر أقل من الحد الأدنى للمخزون أول سوف تصبح أقل منه قريباً.',
    'assets_warrantee_alert' => 'هنالك :count أصل سوف تنتهي فترة الضمان الخاصة به في الأيام :threshold القادمة.| هنالك :count أصول سوف تنتهي فترة الضمان الخاصة بهم في الأيام :threshold القادمة.',
    'license_expiring_alert' => 'هنالك :count رخص سوف تنتهي في الأيام :threshold القادمة.',
    'to_reset' => 'لإعادة تعيين كلمة مرور على :web، رجاءا أكمل هذا النموذج:',
    'type' => 'اكتب',
    'upcoming-audits' => 'هناك :count الأصل الذي سيأتي للمراجعة في غضون :threshold أيام.<unk> هناك :count أصول ستأتي للمراجعة في غضون :threshold أيام.',
    'user' => 'المستخدم',
    'username' => 'اسم المستخدم',
    'welcome' => 'مرحباً :name',
    'welcome_to' => 'مرحبا بكم في :web!',
    'your_credentials' => 'أوراق اعتماد قنص-إيت الخاص بك',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'تذكير: تاريخ تحقق :name يقترب من الموعد النهائي',
    'Expected_Checkin_Date' => 'من المقرر أن يتم التحقق من الأصول التي تم إخراجها إليك في :date',
    'your_assets' => 'عرض الأصول الخاصة بك'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ar/mail.php <==
<?php

return [
    'a_user_canceled' => 'ألغى المستخدم طلب عنصر على الموقع',
    'a_user_requested' => 'طلب مستخدم عنصر على الموقع',
    'accessory_name' => 'اسم الملحق:',
    'additional_notes' => 'ملاحظات إضافية:',
    'admin_has_created' => 'قام مسؤول بإنشاء حساب لك على الموقع :web.',
    'asset' => 'أصل:',
    'asset_name' => 'اسم الأصل:',
    'asset_requested' => 'تم طلب مادة العرض',
    'asset_tag' => 'وسم الأصل',
    'assigned_to' => 'عينت الى',
    'best_regards' => 'أفضل التحيات،',
    'canceled' => 'ملغى:',
    'checkin_date' => 'تاريخ الادخال:',
    'checkout_date' => 'تاريخ الاخراج:',
    'click_to_confirm' => 'يرجى النقر على الرابط التالي لتأكيد حسابك على :web :',
    'click_on_the_link_accessory' => 'الرجاء النقر على الرابط الموجود في الأسفل لتأكيد استلامك للملحق.',
    'click_on_the_link_asset' => 'يرجى النقر على الرابط في الجزء السفلي للتأكد من أنك قد تلقيت مادة العرض.',
    'Confirm_Asset_Checkin' => 'تأكيد تسجيل الأصول',
    'Confirm_Accessory_Checkin' => 'تأكيد تسجيل الأصول',
    'Confirm_accessory_delivery' => 'تأكيد توصيل الأصول',
    'Confirm_license_delivery' => 'تأكيد توصيل الرخصة',
    'Confirm_asset_delivery' => 'تأكيد تسليم الأصول',
    'Confirm_consumable_delivery' => 'تأكيد التسليم المستهلكة',
    'current_QTY' => 'الكمية الحالية',
    'Days' => 'أيام',
    'days' => 'أيام',
    'expecting_checkin_date' => 'تاريخ الادخال المتوقع:',
    'expires' => 'ينتهي',
    'Expiring_Assets_Report' => 'تقرير الأصول المنتهية الصلاحية.',
    'Expiring_Licenses_Report' => 'تقرير التراخيص المنتهية الصلاحية.',
    'hello' => 'مرحبا',
    'hi' => 'مرحبا',
    'i_have_read' => 'لقد قرأت بنود الاستخدام وأوافق عليها، وقد تلقيت هذا البند.',
    'item' => 'عنصر:',
    'Item_Request_Canceled' => 'تم إلغاء طلب العنصر',
    'Item_Requested' => 'العنصر المطلوب',
    'link_to_update_password' => 'يرجى النقر على الرابط التالي لتحديث كلمة المرور الخاصة بك على :web :',
    'login_first_admin' => 'قم بتسجيل الدخول إلى التثبيت الجديد من Snipe-IT باستخدام البيانات أدناه:',
    'login' => 'تسجيل الدخول:',
    'Low_Inventory_Report' => 'تقرير المخزون المنخفض',
    'min_QTY' => 'دقيقة الكمية',
    'name' => 'اسم',
    'new_item_checked' => 'تم فحص عنصر جديد تحت اسمك، التفاصيل أدناه.',
    'password' => 'كلمة المرور:',
    'password_reset' => 'إعادة تعيين كلمة المرور',

    'read_the_terms' => 'يرجى قراءة شروط الاستخدام أدناه.',
    'read_the_terms_and_click' => 'يرجى قراءة بنود الاستخدام أدناه، والنقر على الرابط في الأسفل للتأكد من أنك تقرأ بنود الاستخدام ووافقت عليها، وتلقت مادة العرض.',
    'requested' => 'تم الطلب:',
    'reset_link' => 'رابط إعادة تعيين كلمة المرور',
    'reset_password' => 'انقر هنا لإعادة تعيين كلمة المرور:',
    'serial' => 'الرقم التسلسلي',
    'supplier' => 'المورد',
    'tag' => 'الترميز',
    'test_email' => 'اختبار البريد الإلكتروني من قنص-تكنولوجيا المعلومات',
    'test_mail_text' => 'يعتبر هذا اختبارا من نظام إدارة الأصول Snipe-IT. إذا كنت حصلت على هذا، فان البريد يعمل :)',
    'the_following_item' => 'تم ادخال العنصر التالي: ',
    'low_inventory_alert' => 'هنالك :count عناصر أقل من الحد الأدنى للمخزون أول سوف تصبح أقل منه قريباً.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'هنالك :count رخص سوف تنتهي في الأيام :threshold القادمة.',
    'to_reset' => 'لإعادة تعيين كلمة مرور على :web، رجاءا أكمل هذا النموذج:',
    'type' => 'اكتب',
    'upcoming-audits' => 'هناك :count الأصل الذي سيأتي للمراجعة في غضون :threshold أيام.<unk> هناك :count أصول ستأتي للمراجعة في غضون :threshold أيام.',
    'user' => 'المستخدم',
    'username' => 'اسم المستخدم',
    'welcome' => 'مرحباً :name',
    'welcome_to' => 'مرحبا بكم في :web!',
    'your_credentials' => 'أوراق اعتماد قنص-إيت الخاص بك',
    'Accessory_Checkin_Notification' => 'تم تسحيل الملحق',
    'Asset_Checkin_Notification' => 'تم تسجيل الأصل',
    'License_Checkin_Notification' => 'تم تسجيل الرخصة',
    'Expected_Checkin_Report' => 'تقرير تسجيل الأصول المتوقع',
    'Expected_Checkin_Notification' => 'تذكير: تاريخ تحقق :name يقترب من الموعد النهائي',
    'Expected_Checkin_Date' => 'من المقرر أن يتم التحقق من الأصول التي تم إخراجها إليك في :date',
    'your_assets' => 'عرض الأصول الخاصة بك',
];
